@@ -41,6 +41,7 @@ public:
 		description_ = d;
 	}
 
+	/// \brief Feed's canonical URL. Empty if feed was never fetched.
 	const std::string& link() const
 	{
 		return link_;
@@ -156,10 +157,6 @@ public:
 	{
 		idx = i;
 	}
-	unsigned int get_index()
-	{
-		return idx;
-	}
 
 	void set_order(unsigned int x)
 	{
