@@ -121,7 +121,8 @@ bool DirBrowserFormAction::process_operation(Operation op,
 	case OP_NEXT:
 	case OP_SK_DOWN:
 		if (f.get_focus() == "files") {
-			if (!files_list.move_down(cfg->get_configvalue_as_bool("wrap-scroll"))) {
+			if (!files_list.move_down(
+					cfg->get_configvalue_as_bool("wrap-scroll"))) {
 				f.set_focus("filename");
 			}
 		}
@@ -143,12 +144,14 @@ bool DirBrowserFormAction::process_operation(Operation op,
 		break;
 	case OP_SK_PGUP:
 		if (f.get_focus() == "files") {
-			files_list.move_page_up(cfg->get_configvalue_as_bool("wrap-scroll"));
+			files_list.move_page_up(
+				cfg->get_configvalue_as_bool("wrap-scroll"));
 		}
 		break;
 	case OP_SK_PGDOWN:
 		if (f.get_focus() == "files") {
-			files_list.move_page_down(cfg->get_configvalue_as_bool("wrap-scroll"));
+			files_list.move_page_down(
+				cfg->get_configvalue_as_bool("wrap-scroll"));
 		}
 		break;
 	case OP_QUIT:
